/**
 * Copyright (c) 2000, 2008 IBM Corporation and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation         - initial API and implementation
 *     Diego Sandin (Motorola) - Adapted code from org.eclipse.pde.ui
 */
package org.eclipse.mtj.internal.ui.parts;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredViewer;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.widgets.FormToolkit;

public class TreePart extends StructuredViewerPart {

    /**
     * Constructor for TreePart.
     * 
     * @param buttonLabels
     */
    public TreePart(String[] buttonLabels) {
        super(buttonLabels);
    }

    public TreeViewer getTreeViewer() {
        return (TreeViewer) getViewer();
    }

    /* (non-Javadoc)
     * @see org.eclipse.mtj.internal.ui.parts.SharedPartWithButtons#buttonSelected(org.eclipse.swt.widgets.Button, int)
     */
    @Override
    protected void buttonSelected(Button button, int index) {
    }

    /* (non-Javadoc)
     * @see org.eclipse.mtj.internal.ui.parts.StructuredViewerPart#createStructuredViewer(org.eclipse.swt.widgets.Composite, int, org.eclipse.ui.forms.widgets.FormToolkit)
     */
    @Override
    protected StructuredViewer createStructuredViewer(Composite parent,
            int style, FormToolkit toolkit) {
        style |= SWT.H_SCROLL | SWT.V_SCROLL;
        if (toolkit == null) {
            style |= SWT.BORDER;
        } else {
            style |= toolkit.getBorderStyle();
        }
        TreeViewer treeViewer = createTreeViewer(parent, style);
        treeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
            public void selectionChanged(SelectionChangedEvent e) {
                TreePart.this.selectionChanged((IStructuredSelection) e
                        .getSelection());
            }
        });
        treeViewer.addDoubleClickListener(new IDoubleClickListener() {
            public void doubleClick(DoubleClickEvent e) {
                TreePart.this.handleDoubleClick((IStructuredSelection) e
                        .getSelection());
            }
        });
        return treeViewer;
    }

    protected TreeViewer createTreeViewer(Composite parent, int style) {
        return new TreeViewer(parent, style);
    }

    protected void handleDoubleClick(IStructuredSelection selection) {
    }

    protected void selectionChanged(IStructuredSelection selection) {
    }
}
